//
//  WZAudioPlayerState.h
//  WazeAudio
//
//  Created by Eytan Biala on 6/25/18.
//  Copyright © 2018 Waze. All rights reserved.
//

#import "WZSDKMessage.h"

NS_ASSUME_NONNULL_BEGIN

/** Describes the state of audio playback. */
@interface WZAudioPlayerState : WZSDKMessage

/** Current time of playback in seconds. */
@property(nonatomic, assign, readonly) NSInteger playbackPosition;

/** Speed of playback. */
@property(nonatomic, assign, readonly) float playbackSpeed;

/** `YES` if the player is playing, @c NO if paused. */
@property(nonatomic, assign, readonly) BOOL isPlaying;

/**
 Initialize an object describing the audio playback state.

 @param playbackPosition Current position of playback within the track. `0` if the track has no
 duration.
 @param playbackSpeed Speed of the playback, 1.0f for regular playback.
 @param isPlaying `YES` if the audio is being played.
 */
- (instancetype)initWithPlaybackPosition:(NSInteger)playbackPosition
                           playbackSpeed:(float)playbackSpeed
                               isPlaying:(BOOL)isPlaying;

@end

NS_ASSUME_NONNULL_END
