//
//  WZAudioPlaylist.h
//  AudioSDK
//
//  Copyright © 2018 Waze. All rights reserved.
//

#import <UIKit/UIKit.h>

#import "WZSDKMessage.h"

NS_ASSUME_NONNULL_BEGIN

/** Describes a single playlist. */
@interface WZAudioPlaylist : WZSDKMessage

/** An identifier for the playlist. It must be unique within your system */
@property(nonatomic, copy, readonly) NSString *identifier;

/** The title of the playlist. */
@property(nonatomic, copy, readonly) NSString *title;

/** Image for the playlist. */
@property(nonatomic, nullable, readonly) UIImage *coverImage;

/**
 Returns a playlist with the given identifier, title, and cover image.

 @param identifier Unique identifier for the playlist.
 @param title The playlist's title.
 @param coverImage The playlist's artwork.
 */
- (instancetype)initWithIdentifier:(NSString *)identifier
                             title:(NSString *)title
                        coverImage:(nullable UIImage *)coverImage;

@end

/** A group of playlists. */
@interface WZAudioPlaylistGroup : WZSDKMessage

/** Title for the playlist group. */
@property(nonatomic, copy, readonly, nullable) NSString *groupTitle;

/** The playlists contained within the group */
@property(nonatomic, copy, readonly) NSArray<WZAudioPlaylist *> *playlists;

/**
 Returns a playlist group with the given title and playlists.

 @param groupTitle Playlist group title.
 @param playlists Playlist group contents.
 */
- (instancetype)initWithGroupTitle:(nullable NSString *)groupTitle playlists:(NSArray<WZAudioPlaylist *> *)playlists;

@end

NS_ASSUME_NONNULL_END
