//
//  WZAudioTrack.h
//  AudioSDK
//
//  Copyright © 2018 Waze. All rights reserved.
//

#import <UIKit/UIKit.h>

#import "WZSDKMessage.h"

NS_ASSUME_NONNULL_BEGIN

/** Determines whether to enable or disable UI actions in the player. */
@interface WZAudioTrackOptions : WZSDKMessage

/** `YES` if the user can advance to the next track or fast forward. */
@property(nonatomic, assign) BOOL canFastForward;

/** `YES` if the user can return to the previous track or rewind. */
@property(nonatomic, assign) BOOL canRewind;

/** `YES` if the user can perform the primary action for the given track. */
@property(nonatomic, assign) BOOL canPerformPrimaryAction;

/** `YES` if the icon for the primary action should be highlighted. */
@property(nonatomic, assign) BOOL isPrimaryActionHighlighted;

/** `YES` if the user can perform the secondary action for the given track. */
@property(nonatomic, assign) BOOL canPerformSecondaryAction;

/** `YES` if the icon for the secondary action should be highlighted. */
@property(nonatomic, assign) BOOL isSecondaryActionHighlighted;

@end

/** Encapsulates an audio track and available playback options. */
@interface WZAudioTrack : WZSDKMessage

/** The duration of the track. */
@property(nonatomic, assign) NSTimeInterval trackDuration;

/** Cover image of the album or audio collection, this should not exceed 200x200 px. */
@property(nonatomic, nullable) UIImage *posterImage;

/** Track title. */
@property(nonatomic, copy) NSString *title;

/** Track artist. */
@property(nonatomic, copy) NSString *artist;

/** Track album. */
@property(nonatomic, copy, nullable) NSString *album;

/** Available options for track playback. */
@property(nonatomic, copy) WZAudioTrackOptions *trackOptions;

@end

NS_ASSUME_NONNULL_END
