//
//  WZNavigationStatus.h
//  AudioSDK
//
//  Copyright © 2018 Waze. All rights reserved.
//

#import <Foundation/Foundation.h>

#import "WZSDKMessage.h"

NS_ASSUME_NONNULL_BEGIN

/** Describes all the possible turn instructions. */
typedef NS_ENUM(NSUInteger, WZNavigationInstruction) {
  WZNavigationInstructionNone = 0,
  WZNavigationInstructionTurnLeft,
  WZNavigationInstructionTurnRight,
  WZNavigationInstructionKeepLeft,
  WZNavigationInstructionKeepRight,
  WZNavigationInstructionContinueStraight,
  WZNavigationInstructionRoundaboutEnter,
  WZNavigationInstructionRoundaboutExit,
  WZNavigationInstructionRoundaboutLeft,
  WZNavigationInstructionRoundaboutExitLeft,
  WZNavigationInstructionRoundaboutStraight,
  WZNavigationInstructionRoundaboutExitStraight,
  WZNavigationInstructionRoundaboutRight,
  WZNavigationInstructionRoundaboutExitRight,
  WZNavigationInstructionRoundaboutU,
  WZNavigationInstructionRoundaboutExitU,
  WZNavigationInstructionApproachingDestination,
  WZNavigationInstructionExitLeft,
  WZNavigationInstructionExitRight,
  WZNavigationInstructionWaypointDelay,
  WZNavigationInstructionUTurn,
  WZNavigationInstructionLastDirection,
  WZNavigationInstructionSlightLeft,
  WZNavigationInstructionSharpLeft,
  WZNavigationInstructionSlightRight,
  WZNavigationInstructionSharpright,
  WZNavigationInstructionEnterHOVLane,
  WZNavigationInstructionCount
};

/** Describes the user's navigational status, including information for the next instruction. */
@interface WZNavigationStatus : WZSDKMessage

/** Distance to the next turn instruction, in meters. */
@property(nonatomic, readonly, nullable) NSNumber *distanceToNextInstruction;

/** Type of the next turn instruction. */
@property(nonatomic, readonly) WZNavigationInstruction nextInstruction;

/** Number to exit in a roundabout. */
@property(nonatomic, readonly, nullable) NSNumber *exitNumber;

/** Estimated time of arrival at the destination, in seconds. */
@property(nonatomic, readonly, nullable) NSNumber *estimatedTimeOfArrival;

/** Distance to the destination, in meters. */
@property(nonatomic, readonly, nullable) NSNumber *distanceToArrival;

/** Name of the destination city. */
@property(nonatomic, readonly, nullable) NSString *destinationCity;

/** GeoJSON describing the navigation route being followed. */
@property(nonatomic, readonly, nullable) NSString *routeGeoJson;

/**
 Fully specify the current navigation state.

 @param distanceToNextInstruction Distance to the next instruction
 @param nextInstruction Type of next instruction
 @param exitNumber Roundabout exit number
 @param estimatedTimeOfArrival ETA at destination
 @param distanceToArrival Distance to destination
 @param destinationCity Name of destination city
 @param routeGeoJson Route JSON
 @return an initialized `WZNavigationStatus`
 */
- (instancetype)initWithDistanceToNextInstruction:(nullable NSNumber *)distanceToNextInstruction
                                  nextInstruction:(WZNavigationInstruction)nextInstruction
                                       exitNumber:(nullable NSNumber *)exitNumber
                           estimatedTimeOfArrival:(nullable NSNumber *)estimatedTimeOfArrival
                                distanceToArrival:(nullable NSNumber *)distanceToArrival
                                  destinationCity:(nullable NSString *)destinationCity
                                     routeGeoJson:(nullable NSString *)routeGeoJson;

@end

NS_ASSUME_NONNULL_END
