//
//  WZPlayerConfiguration.h
//  AudioSDK
//
//  Copyright © 2018 Waze. All rights reserved.
//

#import <UIKit/UIKit.h>

#import "WZSDKMessage.h"

@class WZAudioPlaylist;

/** Available icon types for rating/favoriting a track. */
typedef NS_ENUM(NSUInteger, WZAudioPlayerButtonType) {
  WZAudioPlayerButtonTypeNone,
  WZAudioPlayerButtonTypePlus,
  WZAudioPlayerButtonTypeHeart,
  WZAudioPlayerButtonTypeThumbsUp,
  WZAudioPlayerButtonTypeThumbsDown,
  WZAudioPlayerButtonTypeBookmark,
  WZAudioPlayerButtonTypeShuffle,
};

/** Available color scheme for the banner. */
typedef NS_ENUM(NSUInteger, WZBannerColorScheme) {
  WZBannerColorSchemeCustom,
  WZBannerColorSchemeBlue,
  WZBannerColorSchemeGreen,
  WZBannerColorSchemeLight,
  WZBannerColorSchemeDark,
};

NS_ASSUME_NONNULL_BEGIN

/** Options for customizing Waze's audio player and SDK behavior. */
@interface WZPlayerConfiguration : WZSDKMessage

/** Required. The URL scheme to open your app. */
@property(nonatomic, copy) NSString *appURLScheme;

/** Tint color to apply to the player elements to match your app's logo and color scheme. */
@property(nonatomic, copy, nullable) UIColor *highlightColor;

/** Duration to advance when fast forwarding a track. */
@property(nonatomic, assign) NSTimeInterval fastForwardInterval;

/** Duration to go back when rewinding a track. */
@property(nonatomic, assign) NSTimeInterval rewindInterval;

/** Primary icon to show in the player. */
@property(nonatomic, assign) WZAudioPlayerButtonType primaryAction;

/**
 Secondary icon to show in the player if your app has multiple rating/favoriting states, for
 example thumbs up and thumbs down.
 */
@property(nonatomic, assign) WZAudioPlayerButtonType secondaryAction;

/** The @c WZAudioPlayerBannerColorScheme to be used to set the scheme of the banner. */
@property(nonatomic) WZBannerColorScheme bannerScheme;

/**
 The @c UIColor to be used for the banner's background color.
 Default scheme can be used by using the |bannerScheme| instead.
  */
@property(nonatomic, copy) UIColor *bannerBackgroundColor;

/**
 The @c UIColor to be used for the banner's text color.
 Default scheme can be used by using the |bannerScheme| instead.
  */
@property(nonatomic, copy) UIColor *bannerTextColor;

@end

NS_ASSUME_NONNULL_END
