precision mediump float;

uniform float u_time;
uniform float u_rms;
uniform vec2 u_resolution;
uniform sampler2D u_texture;
varying mediump vec2 v_tex_coord;

const float TWO_PI = 6.28318530718;
const float vertices = 16.;
const float startIndex = vertices;
const float endIndex = vertices * 2.;


float getFreq(int x, int count) {
    return texture2D(u_texture, vec2(float(x) / float(count), 0.5)).x;
}


float metaballs(vec2 uv, float time) {
    float timeOsc = sin(time);										// oscillation helper
    float size = 0.1;												// base size
    float radSegment = TWO_PI / vertices;
    for(float i = startIndex; i < endIndex; i++) {					// create x control points
        float rads = i * radSegment;								// get rads for control point
        float radius = getFreq(int(i - startIndex), int(endIndex - startIndex)) * 2.;
        vec2 ctrlPoint = radius * vec2(sin(rads), cos(rads));		// control points in a circle
        size += 1. / pow(i, distance(uv, ctrlPoint));				// metaball calculation
    }
    return size;
}


void main()
{
    float time = u_time * 2.;
    vec2 uv = (2. * v_tex_coord - u_resolution.xy) / u_resolution.y;	// center coordinates
    uv *= 3.; 														// zoom out
    float col = metaballs(uv, time);
    col = smoothstep(0.79, 0.81, col);				// was simple but aliased: smoothstep(0.98, 0.99, col);
    gl_FragColor = vec4((1.0 - sqrt(vec3(col))) * u_rms, 1);
}

