precision mediump float;

uniform highp float u_time;
uniform float u_rms;

uniform vec2 u_resolution;
uniform sampler2D u_texture;
varying mediump vec2 v_tex_coord;

vec3 mixc(vec3 col1, vec3 col2, float v)
{
    v = clamp(v,0.0,1.0);
    return col1+v*(col2-col1);
}

void main()
{
    vec2 uv = v_tex_coord.yx / u_resolution.xy;
    vec2 p = uv*2.0-1.0;
    p.x*=u_resolution.x/u_resolution.y;
    p.y+=0.5;
    
    vec3 col = vec3(0.0);
    vec3 ref = vec3(0.0);
    
    float nBands = 32.0;
    float i = floor(uv.x*nBands);
    float f = fract(uv.x*nBands);
    float band = i/nBands;
    band *= band*band;
    band = band+0.005;
    band *= 1.0/1.005;
    float s = texture2D( u_texture, vec2(band,0.25) ).x;
    
    /* Gradient colors and amount here */
    const int nColors = 4;
    vec3 colors[nColors];
    colors[0] = vec3(0.0,0.0,1.0);
    colors[1] = vec3(0.0,1.0,1.0);
    colors[2] = vec3(1.0,1.0,0.0);
    colors[3] = vec3(1.0,0.0,0.0);
    
    vec3 gradCol = colors[0];
    float n = float(nColors)-1.0;
    for(int i = 1; i < nColors; i++)
    {
        gradCol = mixc(gradCol,colors[i],(s-float(i-1)/n)*n);
    }
    
    col += vec3(1.0-smoothstep(0.0,0.001,p.y-s*1.5));
    col *= gradCol;
    
    ref += vec3(1.0-smoothstep(0.0,-0.001,p.y+s*1.5));
    ref*= gradCol*smoothstep(-0.5,0.5,p.y);
    
    col = mix(ref,col,smoothstep(-0.001,0.001,p.y));
    
    col *= smoothstep(0.125,0.375,f);
    col *= smoothstep(0.875,0.625,f);
    
    col = clamp(col, 0.0, 1.0);
    
//    float dither = noise3D(vec3(p,time))*2.0/256.0;
//    col += dither;
    
    
    gl_FragColor = vec4(col, 1.0);
}

