precision mediump float;

uniform highp float u_time;
uniform float u_rms;

uniform vec2 u_resolution;
uniform sampler2D u_texture;
uniform sampler2D u_texture2;
varying mediump vec2 v_tex_coord;

#define PI 3.1415926535
#define TWO_PI 6.28318530718

#define shadowStr 0.04
#define textureStr 0.05
#define maxHueRange 0.8
#define flipTime 2.
#define edge 0.005

vec3 hsv2rgb(vec3 c){
    vec4 K = vec4(1.0, 2.0 / 3.0, 1.0 / 3.0, 3.0);
    vec3 p = abs(fract(c.xxx + K.xyz) * 6.0 - K.www);
    return c.z * mix(K.xxx, clamp(p - K.xxx, 0.0, 1.0), c.y);
}

//returns 1 for inside circ, 0 for outside
float circle(in vec2 _st, in vec2 pos, in float _radius){
    
    vec2 dist = _st - pos;
    return 1. - smoothstep(_radius, _radius + edge, dot(dist,dist)*4.0);
}

//returns 1 for inside poly, 0 for outside
float polygon(in vec2 _st, in vec2 pos,  in float _radius, in int _sides){
    
    _st -= pos;
    
    // Angle and radius from the current pixel
    float a = atan(_st.x,_st.y) + PI;
    float r = TWO_PI/float(_sides);
    
    // Shaping function that modulate the distance
    float d = cos(floor(.5+a/r)*r-a)*length(_st);
    return 1.0-smoothstep(_radius,_radius + edge,d);
    
}

vec2 rotate2D(vec2 position, float theta)
{
    mat2 m = mat2( cos(theta), -sin(theta), sin(theta), cos(theta) );
    return m * position;
}

float random (vec2 st) {
    return texture2D(u_texture2, st * 200.0).r;
}

float randomRange (in vec2 seed, in float min, in float max) {
    return min + random(seed) * (max - min);
}

vec2 distort(in vec2 uv , float amount)
{
    //pixel displacement
    
    //move displacement map
    vec2 uv2 = uv + vec2(u_time/10.0);
    
    //offset texture sample posn
    //with noise texture rb value
    uv += (texture2D(u_texture2, uv2).rb-vec2(.5))* amount;
    return uv;
}



void main()
{
    //square aspect ratio, centered
    vec2 uv = vec2( v_tex_coord.xy - 0.5*u_resolution.xy ) / min(u_resolution.x,u_resolution.y);
    
    //new rnd every flipTime
    float beat = floor(u_time/flipTime);
    float rndTime = random(vec2(beat) + 3243.324);
    
    //0 - 1 within flipTime
    float fracT = fract(u_time/flipTime);
    
    //randomize grid dims every 4 beats
    float segments = randomRange(vec2(floor(u_time/flipTime/4.)),2.,6.);
    
    
    uv = rotate2D(uv,u_time/20.1);
    
    //slide alternate rows + columns
    float rowId = floor(uv.y * segments );
    float colId = floor(uv.x * segments );
    
    //slide shapes to beat
    float slide = smoothstep(0.,0.3,fracT)/segments;
    
    if (mod(floor(u_time/flipTime),2.) == 0.){
        uv.x += mod(rowId,2.) == 0. ? + slide : -slide;
    }else{
        uv.y += mod(colId,2.) == 0. ? + slide : -slide;
    }
    
    //get a random shape for this tile
    float tileRnd = random(floor(uv * segments ) * rndTime * 0.1);
    int sides = int(floor(tileRnd * 3.) + 3.);
    
    //draw shape
    float isShape = 0.;
    
    //random shape sizes
    float tileRnd2 = random(floor(uv * segments ) * rndTime  );
    float sizeRng = 0.4;
    float radius = 0.27;
    radius *= (1. + ((tileRnd2 - 0.5) * sizeRng)) * u_rms * u_rms * 2.0;
    
    //grid
    uv = fract( uv * segments);
    
    if (sides == 5){
        //some circles
        radius *= 1.25;
        isShape = circle(uv, vec2(0.5), radius);
    }else{
        //make triangles smaller, and move down a tad
        if (sides == 3){
            radius *= 0.7;
            uv.y += 0.08;
        }
        isShape = polygon(uv, vec2(0.5), radius, sides);
    }
    
    //hsl colors
    //0-1 on both axes
    vec2 st = v_tex_coord.xy / u_resolution.xy;
    float hueBck;//background hue
    float hueShp;// shape hue
    
    //new gradients every beat
    
    //bkgnd gradient
    float hstart = random(vec2(beat, 79834));
    float hend = hstart + random(vec2(beat, 345))* maxHueRange - maxHueRange/2.;
    
    hueBck = mix(hstart,hend, st.y + u_time/6.); //simpler
    
    //shape gradient
    hstart = random(vec2(beat, 6045.)) + tileRnd2/6.; //random hue offset
    hend = hstart + random(vec2(beat, 284))* maxHueRange  - maxHueRange/2.;
    
    hueShp = mix(hstart,hend, st.y + u_time/6.);
    
    //mix 2 hsls in rgb
    vec3 colBkgnd =  hsv2rgb(vec3(hueBck, 0.4,0.8 * (st.y *0.5) + 0.5 )); //bkgnd
    vec3 colShp =  hsv2rgb(vec3(hueShp, 0.4,0.9  )); //shape
    
    
    //draw shapes
    vec3 outCol = vec3(mix(colBkgnd, colShp, isShape));
    
    //add noise
    //display independent texture res
    //256 for actual noise res, 200 for slightly blurred
    outCol += (texture2D(u_texture2, st * u_resolution.xy).r - 0.5) * textureStr;
    
    gl_FragColor = vec4(outCol,1.0);
}

